package com.phm.common.core.domain;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.phm.common.constant.HttpStatus;
import com.phm.common.core.domain.model.LoginUser;
import com.phm.common.exception.ServiceException;
import com.phm.common.utils.DateUtils;
import com.phm.common.utils.SecurityUtils;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.ObjectUtils;

import java.io.Serializable;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

/**
 * Entity基类
 *
 * @author phm
 */
@Data
@Slf4j
public class BaseEntity implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 搜索值
     */
    @JsonIgnore
    private String searchValue;

    /**
     * 创建者
     */
    private String createBy;

    /**
     * 创建时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * 更新者
     */
    private String updateBy;

    /**
     * 更新时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;

    /**
     * 备注
     */
    private String remark;

    /**
     * 数据是否删除（1：删除，0有效）
     */
    private Integer isDelete;

    /**
     * 请求参数
     */
    @JsonInclude(JsonInclude.Include.NON_EMPTY)
    private Map<String, Object> params;

    public Map<String, Object> getParams() {
        if (params == null) {
            params = new HashMap<>();
        }
        return params;
    }

    /**
     * 新增数据SET创建和更新信息
     */
    public void initCreatInfo() {
        Date nowDate = DateUtils.getNowDate();
        this.createTime = nowDate;
        this.updateTime = nowDate;
        LoginUser loginUser = null;
        try {
            loginUser = (LoginUser)SecurityUtils.getAuthentication().getPrincipal();
        } catch (Exception ignored) {
            log.error("获取用户信息异常");
        }
        if (ObjectUtils.isNotEmpty(loginUser)) {
            this.createBy = loginUser.getUsername();
            this.updateBy = loginUser.getUsername();
        } else {
            this.createBy = "ANONYMITY";
            this.updateBy = "ANONYMITY";
        }
    }

    /**
     * 更新数据时，SET更新信息
     */
    public void initUpdateInfo() {
        this.updateTime = DateUtils.getNowDate();
        LoginUser loginUser = null;
        try {
            loginUser = (LoginUser)SecurityUtils.getAuthentication().getPrincipal();
        } catch (Exception ignored) {
            log.error("error: 获取用户信息异常");
        }
        this.updateBy = ObjectUtils.isNotEmpty(loginUser) ? loginUser.getUsername() : "ANONYMITY";
    }
}
