package com.phm.manage.config;

import com.phm.common.utils.ip.IpUtils;
import com.phm.manage.domain.GlobalIdRegister;
import com.phm.manage.mapper.GlobalIdRegisterMapper;
import com.phm.manage.util.SnowFlakeIdGenerator;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.util.List;

/**
 * @Description SnowFlakeConfig
 * @Author WGK
 * @Date 2023/9/8 14:33
 */
@Configuration
public class SnowFlakeConfig {

    @Autowired
    private GlobalIdRegisterMapper globalIdRegisterMapper;

    /**
     * 初始化生成ID参数
     *
     * @return bean
     */
    @Bean()
    @ConditionalOnMissingBean(SnowFlakeIdGenerator.class)//用户没有注入自己的bean才装配
    public SnowFlakeIdGenerator getDefaultIdGenerator() {
        GlobalIdRegister globalIdRegister = new GlobalIdRegister();
        globalIdRegister.setMachine(IpUtils.getMac());
        List<GlobalIdRegister> registerList = globalIdRegisterMapper.selectGlobalIdRegisterList(globalIdRegister);
        Long machineId = 1L;
        Long datacenterId = 1L;
        if (CollectionUtils.isEmpty(registerList)) {
            globalIdRegister.setMachineId(1L);
            globalIdRegister.setDatacenterId(1L);
            GlobalIdRegister register = globalIdRegisterMapper.selectGlobalIdRegister();
            if (ObjectUtils.isNotEmpty(register)) {
                machineId = register.getMachineId();
                datacenterId = register.getDatacenterId();
                globalIdRegister.setMachineId(++machineId);
                globalIdRegister.setDatacenterId(datacenterId);
                if (register.getMachineId() >= SnowFlakeIdGenerator.MAX_MACHINE_NUM && register.getDatacenterId() < SnowFlakeIdGenerator.MAX_DATACENTER_NUM) {
                    globalIdRegister.setMachineId(1L);
                    globalIdRegister.setDatacenterId(++datacenterId);
                }
                if (register.getMachineId() >= SnowFlakeIdGenerator.MAX_MACHINE_NUM && register.getDatacenterId() >= SnowFlakeIdGenerator.MAX_DATACENTER_NUM) {
                    globalIdRegister.setDatacenterId(1L);
                    globalIdRegister.setMachineId(1L);
                }
            }
            SnowFlakeIdGenerator snowFlakeIdGenerator = new SnowFlakeIdGenerator(globalIdRegister.getDatacenterId(), globalIdRegister.getMachineId());
            globalIdRegisterMapper.insertGlobalIdRegister(globalIdRegister);
            return snowFlakeIdGenerator;
        } else {
            globalIdRegister.setDatacenterId(registerList.get(0).getDatacenterId());
            globalIdRegister.setMachineId(registerList.get(0).getMachineId());
            return new SnowFlakeIdGenerator(globalIdRegister.getDatacenterId(), globalIdRegister.getMachineId());
        }
    }

}
