package com.phm.manage.controller;

import com.phm.common.annotation.Log;
import com.phm.common.core.controller.BaseController;
import com.phm.common.core.domain.AjaxResult;
import com.phm.common.core.page.TableDataInfo;
import com.phm.common.enums.BusinessType;
import com.phm.common.utils.poi.ExcelUtil;
import com.phm.manage.domain.GlobalIdRegister;
import com.phm.manage.service.IGlobalIdRegisterService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 全局机器ID注册Controller
 *
 * @author phm
 * @date 2023-09-08
 */
@RestController
@RequestMapping("/manage/register")
public class GlobalIdRegisterController extends BaseController {
    @Autowired
    private IGlobalIdRegisterService globalIdRegisterService;

    /**
     * 查询全局机器ID注册列表
     */
    @PreAuthorize("@ss.hasPermi('manage:register:list')")
    @GetMapping("/list")
    public TableDataInfo list(GlobalIdRegister globalIdRegister) {
        startPage();
        List<GlobalIdRegister> list = globalIdRegisterService.selectGlobalIdRegisterList(globalIdRegister);
        return getDataTable(list);
    }

    /**
     * 导出全局机器ID注册列表
     */
    @PreAuthorize("@ss.hasPermi('manage:register:export')")
    @Log(title = "全局机器ID注册", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, GlobalIdRegister globalIdRegister) {
        List<GlobalIdRegister> list = globalIdRegisterService.selectGlobalIdRegisterList(globalIdRegister);
        ExcelUtil<GlobalIdRegister> util = new ExcelUtil<GlobalIdRegister>(GlobalIdRegister.class);
        util.exportExcel(response, list, "全局机器ID注册数据");
    }

    /**
     * 获取全局机器ID注册详细信息
     */
    @PreAuthorize("@ss.hasPermi('manage:register:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(globalIdRegisterService.selectGlobalIdRegisterById(id));
    }

    /**
     * 新增全局机器ID注册
     */
    @PreAuthorize("@ss.hasPermi('manage:register:add')")
    @Log(title = "全局机器ID注册", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody GlobalIdRegister globalIdRegister) {
        return toAjax(globalIdRegisterService.insertGlobalIdRegister(globalIdRegister));
    }

    /**
     * 修改全局机器ID注册
     */
    @PreAuthorize("@ss.hasPermi('manage:register:edit')")
    @Log(title = "全局机器ID注册", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody GlobalIdRegister globalIdRegister) {
        return toAjax(globalIdRegisterService.updateGlobalIdRegister(globalIdRegister));
    }

    /**
     * 删除全局机器ID注册
     */
    @PreAuthorize("@ss.hasPermi('manage:register:remove')")
    @Log(title = "全局机器ID注册", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(globalIdRegisterService.deleteGlobalIdRegisterByIds(ids));
    }
}
