package com.phm.manage.controller;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.phm.common.annotation.Log;
import com.phm.common.core.controller.BaseController;
import com.phm.common.core.domain.AjaxResult;
import com.phm.common.core.page.TableDataInfo;
import com.phm.common.enums.BusinessType;
import com.phm.common.utils.poi.ExcelUtil;
import com.phm.manage.domain.ModelInfo;
import com.phm.manage.service.IModelService;

/**
 * 模型Controller
 *
 * @author phm
 * @date 2023-11-15
 */
@RestController
@RequestMapping("/manage/model")
public class ModelInfoController extends BaseController {
    @Autowired
    private IModelService modelService;

    /**
     * 查询模型列表
     */
    @PreAuthorize("@ss.hasPermi('manage:model:list')")
    @GetMapping("/list")
    public TableDataInfo list(ModelInfo modelInfo) {
        startPage();
        List<ModelInfo> list = modelService.selectModelInfoList(modelInfo);
        return getDataTable(list);
    }

    /**
     * 导出模型列表
     */
    @PreAuthorize("@ss.hasPermi('manage:model:export')")
    @Log(title = "模型信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ModelInfo modelInfo) {
        List<ModelInfo> list = modelService.selectModelInfoList(modelInfo);
        ExcelUtil<ModelInfo> util = new ExcelUtil<ModelInfo>(ModelInfo.class);
        util.exportExcel(response, list, "模型数据");
    }

    /**
     * 获取模型详细信息
     */
    @PreAuthorize("@ss.hasPermi('manage:model:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(modelService.selectModelById(id));
    }

    /**
     * 新增模型
     */
    @PreAuthorize("@ss.hasPermi('manage:model:add')")
    @Log(title = "模型信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ModelInfo modelInfo) {
        return toAjax(modelService.insertModelInfo(modelInfo));
    }

    /**
     * 修改模型
     */
    @PreAuthorize("@ss.hasPermi('manage:model:edit')")
    @Log(title = "模型信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ModelInfo modelInfo) {
        return toAjax(modelService.updateModelInfo(modelInfo));
    }

    /**
     * 删除模型
     */
    @PreAuthorize("@ss.hasPermi('manage:model:remove')")
    @Log(title = "模型信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(modelService.deleteModelInfoByIds(ids));
    }
}
