package com.phm.manage.controller.externalInter;

import com.alibaba.fastjson2.JSON;
import com.phm.common.annotation.Anonymous;
import com.phm.common.core.domain.entity.SysDictData;
import com.phm.common.utils.StringUtils;
import com.phm.common.utils.bean.BeanUtils;
import com.phm.manage.domain.OrderInfo;
import com.phm.manage.domain.common.CommonResult;
import com.phm.manage.domain.common.CommonResultXML;
import com.phm.manage.domain.common.OrderXmlVO;
import com.phm.manage.domain.Sortie;
import com.phm.manage.enums.OrderStatus;
import com.phm.manage.service.IOrderInfoService;
import com.phm.manage.service.ISortieService;
import com.phm.system.service.ISysDictTypeService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;

/**
 * 对外提供接口
 *
 * @author phm
 * @date 2023-08-22
 */
@RestController
@Anonymous
@RequestMapping("/publicservice")
@Slf4j
public class ExternalInterfaceController {

    @Autowired
    private ISysDictTypeService dictTypeService;

    @Autowired
    private ISortieService sortieService;

    @Autowired
    private IOrderInfoService orderInfoService;


    /**
     * 指令接收API
     *
     * @param orderXmlVO 入参
     * @return res
     */
    @PostMapping(value = "/receive", consumes = {MediaType.APPLICATION_XML_VALUE, MediaType.TEXT_XML_VALUE},
            produces = MediaType.APPLICATION_XML_VALUE)
    public CommonResultXML<OrderInfo> receive(@RequestBody OrderXmlVO orderXmlVO) {
        log.info("指令入参：{}", orderXmlVO.toString());
        OrderInfo orderInfo = new OrderInfo();
        BeanUtils.copyBeanProp(orderInfo, orderXmlVO);
        orderInfo.setContent(JSON.toJSONString(orderXmlVO));
        // set待执行状态
        orderInfo.setStatus(OrderStatus.S_0.getCode());
        // TODO orderInfo 入库
        return CommonResultXML.buildSuccess();
    }

    /**
     * 根据字典类型查询字典数据信息
     */
    @GetMapping(value = "/type/{dictType}", produces = MediaType.APPLICATION_JSON_VALUE)
    public CommonResult<List<SysDictData>> dictType(@PathVariable String dictType) {
        log.info("dictType：{}", dictType);
        List<SysDictData> data = dictTypeService.selectDictDataByType(dictType);
        if (StringUtils.isNull(data)) {
            data = new ArrayList<SysDictData>();
        }
        return CommonResult.success(data);
    }

    /**
     * 查询架次信息
     *
     * @return 架次列表
     */
    @GetMapping(value = "/sortieList", produces = MediaType.APPLICATION_JSON_VALUE)
    public CommonResult<List<Sortie>> sortieList() {
        List<Sortie> data = sortieService.selectSortieList(null);
        return CommonResult.success(data);
    }

    /**
     * 监测模块状态
     *
     * @param type 模块类型
     * @return 模块状态信息
     */
    @GetMapping(value = "/monitorModule/{type}", produces = MediaType.APPLICATION_JSON_VALUE)
    public CommonResult monitor(@PathVariable String type) {
        log.info("monitor:{}", type);
        return CommonResult.buildSuccess();
    }
}
