package com.phm.manage.service.impl;

import java.io.File;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.List;

import org.springframework.stereotype.Service;

import com.phm.manage.service.IBackupRestoreService;

import cn.hutool.core.io.FileUtil;
import lombok.extern.slf4j.Slf4j;

/**
 * @Description BackupRestoreService
 * @Author WGK
 * @Date 2023/11/30 14:02
 */
@Service
@Slf4j
public class BackupRestoreService implements IBackupRestoreService {
    @Override
    public boolean fileCopyBackup(String sourceFolderPath, String targetFolderPath) {
        copyFile(sourceFolderPath, targetFolderPath, false);
        return true;
    }

    private static void copyFile(String sourceFolderPath, String targetFolderPath, boolean isAllCopy) {
        // 获取源文件夹和目标文件夹中的文件列表
        List<File> sourceFiles = FileUtil.loopFiles(sourceFolderPath);
        List<File> targetFiles = FileUtil.loopFiles(targetFolderPath);

        // 执行增量复制操作
        for (File sourceFile : sourceFiles) {
            // 源文件相对于源文件夹的相对路径
            String relativePath = FileUtil.subPath(sourceFolderPath, sourceFile.getAbsolutePath());

            // 目标文件路径
            Path targetPath = Paths.get(targetFolderPath, relativePath);

            // 目标文件
            File targetFile = targetPath.toFile();
            // 如果源文件是新添加或者修改过的，则进行复制
            if (isAllCopy || !targetFiles.contains(targetFile)
                || sourceFile.lastModified() > targetFile.lastModified()) {
                FileUtil.copy(sourceFile, targetFile, true);
            }
        }
    }

    @Override
    public boolean fileCopyRestore(String sourceFolderPath, String targetFolderPath) {
        // 执行复制操作
        copyFile(sourceFolderPath, targetFolderPath, true);
        return true;
    }
}
