package com.phm.manage.service.impl;

import java.util.Arrays;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.dromara.easyes.core.conditions.select.LambdaEsQueryWrapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.phm.manage.domain.FaultCase;
import com.phm.manage.es.mapper.EsFaultCaseMapper;
import com.phm.manage.mapper.FaultCaseMapper;
import com.phm.manage.service.IFaultCaseService;
import com.phm.manage.util.SnowFlakeIdGenerator;

/**
 * 故障案例信息Service业务层处理
 *
 * @author phm
 * @date 2023-08-22
 */
@Service
public class FaultCaseServiceImpl implements IFaultCaseService {
    @Autowired
    private FaultCaseMapper faultCaseMapper;

    @Autowired
    private SnowFlakeIdGenerator snowFlakeIdGenerator;

    @Autowired
    private EsFaultCaseMapper esFaultCaseMapper;

    /**
     * 查询故障案例信息
     *
     * @param id 故障案例信息主键
     * @return 故障案例信息
     */
    @Override
    public FaultCase selectFaultCaseById(Long id) {
        return faultCaseMapper.selectFaultCaseById(id);
    }

    /**
     * 查询故障案例信息列表
     *
     * @param faultCase 故障案例信息
     * @return 故障案例信息
     */
    @Override
    public List<FaultCase> selectFaultCaseList(FaultCase faultCase) {
        LambdaEsQueryWrapper<FaultCase> wrapper = new LambdaEsQueryWrapper<>();
        wrapper.match(StringUtils.isNotBlank(faultCase.getDescription()), "content", faultCase.getDescription(), 5.0f)
            .or()
            .match(StringUtils.isNotBlank(faultCase.getCaseName()), FaultCase::getCaseName, faultCase.getCaseName())
            .or()
            .match(StringUtils.isNotBlank(faultCase.getCaseNumber()), FaultCase::getCaseNumber,
                faultCase.getCaseNumber())
            .or()
            .match(StringUtils.isNotBlank(faultCase.getLocation()), FaultCase::getLocation, faultCase.getLocation())
            .or()
            .match(StringUtils.isNotBlank(faultCase.getParameter()), FaultCase::getParameter, faultCase.getParameter())
            .or()
            .match(StringUtils.isNotBlank(faultCase.getSolution()), FaultCase::getSolution, faultCase.getSolution());
        if (!esFaultCaseMapper.existsIndex("fault_case")) {
            esFaultCaseMapper.createIndex();
        }
        return esFaultCaseMapper.selectList(wrapper);
    }

    /**
     * 修改故障案例信息
     *
     * @param faultCase 故障案例信息
     * @return 结果
     */
    @Override
    public int updateFaultCase(FaultCase faultCase) {
        faultCase.setEsId(String.valueOf(faultCase.getId()));
        esFaultCaseMapper.updateById(faultCase);
        return faultCaseMapper.updateFaultCase(faultCase);
    }

    /**
     * 新增故障案例信息
     *
     * @param faultCase 故障案例信息
     * @return 结果
     */
    @Override
    public int insertFaultCase(FaultCase faultCase) {
        faultCase.setId(snowFlakeIdGenerator.nextId());
        faultCase.setEsId(String.valueOf(faultCase.getId()));
        esFaultCaseMapper.insert(faultCase);
        return faultCaseMapper.insertFaultCase(faultCase);
    }

    /**
     * 批量删除故障案例信息
     *
     * @param ids 需要删除的故障案例信息主键
     * @return 结果
     */
    @Override
    public int deleteFaultCaseByIds(Long[] ids) {
        esFaultCaseMapper.deleteBatchIds(Arrays.asList(ids));
        return faultCaseMapper.deleteFaultCaseByIds(ids);
    }

    /**
     * 删除故障案例信息信息
     *
     * @param id 故障案例信息主键
     * @return 结果
     */
    @Override
    public int deleteFaultCaseById(Long id) {
        esFaultCaseMapper.deleteById(id);
        return faultCaseMapper.deleteFaultCaseById(id);
    }

    @Override
    public List<FaultCase> findFaultCaseList(String description) {
        LambdaEsQueryWrapper<FaultCase> wrapper = new LambdaEsQueryWrapper<>();
        wrapper.queryStringQuery(description);
        return esFaultCaseMapper.selectList(wrapper);
    }
}
