package com.phm.manage.service.impl;

import com.phm.common.utils.ip.IpUtils;
import com.phm.manage.domain.GlobalIdRegister;
import com.phm.manage.mapper.GlobalIdRegisterMapper;
import com.phm.manage.service.IGlobalIdRegisterService;
import com.phm.manage.util.SnowFlakeIdGenerator;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 全局机器ID注册Service业务层处理
 *
 * @author phm
 * @date 2023-09-08
 */
@Service
public class GlobalIdRegisterServiceImpl implements IGlobalIdRegisterService {
    @Autowired
    private GlobalIdRegisterMapper globalIdRegisterMapper;

    /**
     * 查询全局机器ID注册
     *
     * @param id 全局机器ID注册主键
     * @return 全局机器ID注册
     */
    @Override
    public GlobalIdRegister selectGlobalIdRegisterById(Long id) {
        return globalIdRegisterMapper.selectGlobalIdRegisterById(id);
    }

    /**
     * 查询全局机器ID注册列表
     *
     * @param globalIdRegister 全局机器ID注册
     * @return 全局机器ID注册
     */
    @Override
    public List<GlobalIdRegister> selectGlobalIdRegisterList(GlobalIdRegister globalIdRegister) {
        return globalIdRegisterMapper.selectGlobalIdRegisterList(globalIdRegister);
    }

    /**
     * 新增全局机器ID注册
     *
     * @param globalIdRegister 全局机器ID注册
     * @return 结果
     */
    @Override
    public int insertGlobalIdRegister(GlobalIdRegister globalIdRegister) {
        return globalIdRegisterMapper.insertGlobalIdRegister(globalIdRegister);
    }

    /**
     * 修改全局机器ID注册
     *
     * @param globalIdRegister 全局机器ID注册
     * @return 结果
     */
    @Override
    public int updateGlobalIdRegister(GlobalIdRegister globalIdRegister) {
        return globalIdRegisterMapper.updateGlobalIdRegister(globalIdRegister);
    }

    /**
     * 批量删除全局机器ID注册
     *
     * @param ids 需要删除的全局机器ID注册主键
     * @return 结果
     */
    @Override
    public int deleteGlobalIdRegisterByIds(Long[] ids) {
        return globalIdRegisterMapper.deleteGlobalIdRegisterByIds(ids);
    }

    /**
     * 删除全局机器ID注册信息
     *
     * @param id 全局机器ID注册主键
     * @return 结果
     */
    @Override
    public int deleteGlobalIdRegisterById(Long id) {
        return globalIdRegisterMapper.deleteGlobalIdRegisterById(id);
    }
}
