package com.phm.manage.service.impl;

import com.phm.common.utils.DateUtils;
import com.phm.manage.domain.OrderConfig;
import com.phm.manage.mapper.OrderConfigMapper;
import com.phm.manage.service.IOrderConfigService;
import com.phm.manage.util.SnowFlakeIdGenerator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 指令配置Service业务层处理
 *
 * @author phm
 * @date 2023-10-07
 */
@Service
public class OrderConfigServiceImpl implements IOrderConfigService {
    @Autowired
    private OrderConfigMapper orderConfigMapper;

    @Autowired
    private SnowFlakeIdGenerator snowFlakeIdGenerator;

    /**
     * 查询指令配置
     *
     * @param id 指令配置主键
     * @return 指令配置
     */
    @Override
    public OrderConfig selectOrderConfigById(Long id) {
        return orderConfigMapper.selectOrderConfigById(id);
    }

    @Override
    public OrderConfig selectOrderConfigByCode(String code) {
        return orderConfigMapper.selectOrderConfigByCode(code);
    }

    /**
     * 查询指令配置列表
     *
     * @param orderConfig 指令配置
     * @return 指令配置
     */
    @Override
    public List<OrderConfig> selectOrderConfigList(OrderConfig orderConfig) {
        return orderConfigMapper.selectOrderConfigList(orderConfig);
    }

    /**
     * 新增指令配置
     *
     * @param orderConfig 指令配置
     * @return 结果
     */
    @Override
    public int insertOrderConfig(OrderConfig orderConfig) {
        orderConfig.initCreatInfo();
        orderConfig.setId(snowFlakeIdGenerator.nextId());
        return orderConfigMapper.insertOrderConfig(orderConfig);
    }

    /**
     * 修改指令配置
     *
     * @param orderConfig 指令配置
     * @return 结果
     */
    @Override
    public int updateOrderConfig(OrderConfig orderConfig) {
        orderConfig.initUpdateInfo();
        orderConfig.setUpdateTime(DateUtils.getNowDate());
        return orderConfigMapper.updateOrderConfig(orderConfig);
    }

    /**
     * 批量删除指令配置
     *
     * @param ids 需要删除的指令配置主键
     * @return 结果
     */
    @Override
    public int deleteOrderConfigByIds(Long[] ids) {
        return orderConfigMapper.deleteOrderConfigByIds(ids);
    }

    /**
     * 删除指令配置信息
     *
     * @param id 指令配置主键
     * @return 结果
     */
    @Override
    public int deleteOrderConfigById(Long id) {
        return orderConfigMapper.deleteOrderConfigById(id);
    }
}
