package com.phm.manage.service.impl;

import java.util.List;

import cn.hutool.json.JSONArray;
import com.phm.manage.util.CsvUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.phm.common.utils.DateUtils;
import com.phm.manage.domain.SortieParameter;
import com.phm.manage.mapper.SortieParameterMapper;
import com.phm.manage.service.ISortieParameterService;
import com.phm.manage.util.SnowFlakeIdGenerator;

/**
 * @Description SortieParameterService
 * @Author WGK
 * @Date 2023/11/21 17:15
 */
@Service
public class SortieParameterService implements ISortieParameterService {
    @Autowired
    private SortieParameterMapper sortieParameterMapper;

    @Autowired
    private SnowFlakeIdGenerator snowFlakeIdGenerator;

    /**
     * 查询模型参数信息
     *
     * @param id 模型参数信息主键
     * @return 模型参数信息
     */
    @Override
    public SortieParameter selectSortieParameterById(Long id) {
        return sortieParameterMapper.selectSortieParameterById(id);
    }

    /**
     * 查询模型参数信息列表
     *
     * @param sortieParameter 模型参数信息
     * @return 模型参数信息
     */
    @Override
    public List<SortieParameter> selectSortieParameterList(SortieParameter sortieParameter) {
        return sortieParameterMapper.selectSortieParameterList(sortieParameter);
    }

    /**
     * 新增模型参数信息
     *
     * @param sortieParameter 模型参数信息
     * @return 结果
     */
    @Override
    public int insertSortieParameter(SortieParameter sortieParameter) {
        sortieParameter.setCreateTime(DateUtils.getNowDate());
        sortieParameter.setId(snowFlakeIdGenerator.nextId());
        return sortieParameterMapper.insertSortieParameter(sortieParameter);
    }

    /**
     * 修改模型参数信息
     *
     * @param sortieParameter 模型参数信息
     * @return 结果
     */
    @Override
    public int updateSortieParameter(SortieParameter sortieParameter) {
        sortieParameter.setUpdateTime(DateUtils.getNowDate());
        return sortieParameterMapper.updateSortieParameter(sortieParameter);
    }

    /**
     * 批量删除模型参数信息
     *
     * @param ids 需要删除的模型参数信息主键
     * @return 结果
     */
    @Override
    public int deleteSortieParameterByIds(Long[] ids) {
        return sortieParameterMapper.deleteSortieParameterByIds(ids);
    }

    /**
     * 删除模型参数信息信息
     *
     * @param id 模型参数信息主键
     * @return 结果
     */
    @Override
    public int deleteSortieParameterById(Long id) {
        return sortieParameterMapper.deleteSortieParameterById(id);
    }

    @Override
    public String getSortieData(Long id) {
        SortieParameter sortieParameter = sortieParameterMapper.selectSortieParameterById(id);
        return CsvUtils.fileCsvToJson(sortieParameter.getDataPath()).toString();
    }
}
