package com.phm.netty.client;

import com.phm.netty.client.handler.NettyClientInitialize;
import com.phm.netty.config.NettyTcpProperties;
import io.netty.bootstrap.Bootstrap;
import io.netty.channel.ChannelFuture;
import io.netty.channel.ChannelOption;
import io.netty.channel.nio.NioEventLoopGroup;
import io.netty.channel.socket.nio.NioSocketChannel;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

/**
 * @Description NettyClient
 * @Author WGK
 * @Date 2023/9/15 11:30
 */
@Component
@Slf4j
public class NettyTcpClient {
    final
    NettyTcpProperties nettyTcpProperties;

    public NettyTcpClient(NettyTcpProperties nettyTcpProperties) {
        this.nettyTcpProperties = nettyTcpProperties;
    }

    /**
     * 启动netty服务端
     */
    public void start() {
//        connect(nettyProperties.getRemoteHost(), nettyProperties.getRemotePort());
        connect("192.168.0.101", 8888);
    }

    public void connect(final String host, final int port) {
        NioEventLoopGroup group = new NioEventLoopGroup();
        Bootstrap bootstrap = new Bootstrap()
                .group(group).channel(NioSocketChannel.class)
                .option(ChannelOption.TCP_NODELAY, true)
                .handler(new NettyClientInitialize(nettyTcpProperties));
        try {
            ChannelFuture channelFuture = bootstrap.connect(host, port).sync();
            channelFuture.channel().closeFuture().sync();
        } catch (InterruptedException exception) {
            log.error("启动客户端异常！！");
            log.error(exception.getMessage());
        } finally {
            // 关闭连接
            group.shutdownGracefully();
        }
        log.info("启动Netty客户端: {}", nettyTcpProperties.getPort());
    }
}
