package com.phm.netty.client.handler;

import com.phm.netty.domain.Message;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.SimpleChannelInboundHandler;
import lombok.extern.slf4j.Slf4j;

/**
 * @Description ClientListenerHandler 客户端业务监听
 * @Author WGK
 * @Date 2023/9/15 9:22
 */
@Slf4j
public class ClientListenerHandler extends SimpleChannelInboundHandler<Message> {

    /**
     * 连接服务端
     *
     * @param context 上下文
     */
    @Override
    public void channelActive(ChannelHandlerContext context) {
        log.info("{}连上了服务器", context.channel().remoteAddress());
    }

    /**
     * 断开服务器
     *
     * @param context 上下文
     */
    @Override
    public void channelInactive(ChannelHandlerContext context) {
        log.info("{}断开了服务器", context.channel().remoteAddress());
        context.fireChannelInactive();
    }

    /**
     * 接收到客户端数据，业务处理
     *
     * @param context 上下文
     * @param message 消息信息
     * @throws Exception 异常
     */
    @Override
    protected void channelRead0(ChannelHandlerContext context, Message message) throws Exception {
        log.info("收到服务端的消息:{}", message.getData());
        context.channel().close();
    }

    /**
     * 异常发生时候调用
     *
     * @param context 上下文
     * @param cause 异常
     */
    @Override
    public void exceptionCaught(ChannelHandlerContext context, Throwable cause) {
        log.error("{}连接发生异常", context.channel().remoteAddress());
        log.error(cause.getCause().toString());
        context.close();
    }
}
