package com.phm.netty.client.handler;

import com.phm.netty.config.NettyTcpProperties;
import com.phm.netty.codec.message.MessageDecodeHandler;
import com.phm.netty.codec.message.MessageEncodeHandler;
import io.netty.buffer.ByteBuf;
import io.netty.buffer.Unpooled;
import io.netty.channel.ChannelInitializer;
import io.netty.channel.ChannelPipeline;
import io.netty.channel.socket.SocketChannel;
import org.springframework.stereotype.Component;

/**
 * @Description NettyClientInitialize 客户端初始类
 * @Author WGK
 * @Date 2023/9/15 9:21
 */
@Component
public class NettyClientInitialize extends ChannelInitializer<SocketChannel> {

    final
    NettyTcpProperties nettyTcpProperties;

    public NettyClientInitialize(NettyTcpProperties nettyTcpProperties) {
        this.nettyTcpProperties = nettyTcpProperties;
    }

    @Override
    protected void initChannel(SocketChannel socketChannel) throws Exception {
        // 数据分割符
        String delimiterStr = nettyTcpProperties.getSeparator();
        ByteBuf delimiter = Unpooled.copiedBuffer(delimiterStr.getBytes());
        ChannelPipeline pipeline = socketChannel.pipeline();
        // 使用自定义处理拆包/沾包，并且每次查找的最大长度为1024字节
//        pipeline.addLast(new DelimiterBasedFrameDecoder(1024, delimiter));
        pipeline.addLast(new MessageEncodeHandler());
        pipeline.addLast(new MessageDecodeHandler());
        pipeline.addLast(new ClientListenerHandler());
    }
}
