package com.phm.netty.client.handler;

import java.util.List;

import javax.annotation.PostConstruct;

import cn.hutool.core.io.FileUtil;
import cn.hutool.core.util.CharsetUtil;
import com.phm.netty.enums.OrderEnum;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.phm.common.exception.GlobalException;
import com.phm.netty.domain.Message;
import com.phm.netty.service.IProcessService;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.ByteBufUtil;
import io.netty.channel.ChannelHandler;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.SimpleChannelInboundHandler;
import io.netty.channel.socket.DatagramPacket;
import io.netty.util.AttributeKey;
import lombok.extern.slf4j.Slf4j;

/**
 * @Description NettyUdpClientHandler
 * @Author WGK
 * @Date 2023/10/30 15:30
 */
@ChannelHandler.Sharable
@Slf4j
@Component
public class NettyUdpClientHandler extends SimpleChannelInboundHandler<DatagramPacket> {

    @Autowired
    IProcessService processService;
    private static NettyUdpClientHandler nettyUdpClientHandler;

    @PostConstruct
    public void init() {
        nettyUdpClientHandler = this;
    }

    @Override
    protected void channelRead0(ChannelHandlerContext ctx, DatagramPacket packet) throws Exception {
        String data =
        FileUtil.readString("D:\\phm\\dataPath\\参数数据.json", CharsetUtil.CHARSET_UTF_8);
        // TODO 这里测试数据
        Message message = new Message();
        message.setType(OrderEnum.ORDER_CONFIG.getType()).setTarget("GPHM").setSource("SPHM")
        .setData("{\"cmdId\": \"getConfig\", \"params\":" + data + "}");
        // 获取自定义值
        String sortieNo = ctx.channel().attr(AttributeKey.valueOf("customKey")).get().toString();
        final ByteBuf buf = packet.content();
        try {
            log.info("channelId---:{}", ctx.channel().id().toString());
            byte[] bytes = ByteBufUtil.getBytes(buf);
            Message msg = Message.getMessage(Message.msgToBytes(message));
            // Message msg = Message.getMessage(bytes);
            if (msg == null) {
                log.info("无数据传输");
                return;
            }
            // 处理数据
            List<String> list = nettyUdpClientHandler.processService.handleData(msg, sortieNo);
            ctx.close();
        } catch (Exception e) {
            log.error("channelRead=={}", e.getMessage());
            throw new GlobalException("在线下载数据异常，请重新下载");
        }
    }

    /**
     * 重写方法 结构： 1.public class BootNettyUdpClientSimpleChannelInboundHandler extends
     * SimpleChannelInboundHandler<DatagramPacket> 2.public abstract class SimpleChannelInboundHandler<I> extends
     * ChannelInboundHandlerAdapter 3.public class ChannelInboundHandlerAdapter extends ChannelHandlerAdapter implements
     * ChannelInboundHandler ChannelInboundHandlerAdapter类有诸多方法可以重写，可以根据具体需求来写
     */
    @Override
    public void channelReadComplete(ChannelHandlerContext ctx) throws Exception {
        super.channelReadComplete(ctx);
        log.info("关闭channel,channelId---:{}", ctx.channel().id().toString());
        ctx.close();
    }

    @Override
    public void exceptionCaught(ChannelHandlerContext ctx, Throwable cause) throws Exception {
        cause.printStackTrace();
        ctx.close();
    }
}
