package com.phm.netty.codec.hexbyte;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.ByteBufUtil;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.ByteToMessageDecoder;

import java.util.List;

/**
 * @Description HexByteArrayDecoder 自定义的解码器，将字节转换为十六进制字节数组
 * @Author WGK
 * @Date 2023/9/21 14:26
 */
public class HexByteArrayDecoder extends ByteToMessageDecoder {
    @Override
    protected void decode(ChannelHandlerContext ctx, ByteBuf in, List<Object> out) throws Exception {
        // 检查是否有足够的字节可读
        if (in.readableBytes() < 2) {
            return;
        }

        // 读取前4个字节以获取消息长度
        int messageLength = in.readInt();

        // 检查是否有足够的字节可读以获取完整消息
        if (in.readableBytes() < messageLength) {
            return;
        }

        // 读取消息内容
        ByteBuf messageBytes = in.readBytes(messageLength);

        // 将消息内容转换为字节数组
        byte[] messageArray = new byte[messageBytes.readableBytes()];
        messageBytes.readBytes(messageArray);

        // 在这里，您可以将字节数组转换为您需要的数据类型，如字符串、整数等，具体取决于您的数据格式。

        // 将解码后的消息添加到输出列表，以便后续处理
        out.add(messageArray);
    }
}
