package com.phm.netty.config;

import com.phm.netty.server.NettyTcpServerInitialize;
import io.netty.bootstrap.ServerBootstrap;
import io.netty.channel.ChannelOption;
import io.netty.channel.nio.NioEventLoopGroup;
import io.netty.channel.socket.nio.NioServerSocketChannel;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * @Description NettyConfig 配置
 * @Author WGK
 * @Date 2023/9/14 11:37
 */
@Configuration
@EnableConfigurationProperties
public class NettyTcpConfig {

    @Autowired
    NettyTcpProperties nettyTcpProperties;
    /**
     * boss线程池-进行客户端连接
     *
     * @return NioEventLoopGroup
     */
    @Bean
    public NioEventLoopGroup boosGroup() {
        return new NioEventLoopGroup(nettyTcpProperties.getBoss());
    }

    /**
     * worker线程池-进行业务处理
     *
     * @return NioEventLoopGroup
     */
    @Bean
    public NioEventLoopGroup workerGroup() {
        return new NioEventLoopGroup(nettyTcpProperties.getWorker());
    }

    /**
     * 服务端启动器，监听客户端连接
     *
     * @return ServerBootstrap
     */
    @Bean
    public ServerBootstrap serverBootstrap() {
        return new ServerBootstrap()
                // 指定使用的线程组
                .group(boosGroup(), workerGroup())
                // 指定使用的通道
                .channel(NioServerSocketChannel.class)
                // 指定连接超时时间
                .option(ChannelOption.CONNECT_TIMEOUT_MILLIS, nettyTcpProperties.getTimeout())
                // 指定worker处理器
                .childHandler(new NettyTcpServerInitialize());
    }
}
