package com.phm.netty.enums;

import com.phm.netty.domain.Message;
import lombok.Getter;

import java.util.Arrays;
import java.util.List;
import java.util.Optional;
import java.util.stream.Collectors;

/**
 * @Description OrderEnum 指令类型枚举类
 * @Author WGK
 * @Date 2023/9/14 11:47
 */
@Getter
public enum OrderEnum {

    PARAMETER((short) 0, "参数传输"),
    COMMON((short) 1, "通用指令发送，具体指令类型有指令本身定义"),
    RESPONSE((short) 2, "指令应答"),
    TIMING((short) 3, "校时"),
    ORDER_CONFIG((short) 4, "指令配置获取"),
    SIMULATION((short) 5, "数链仿真系统获取数据"),
    AIRBORNE((short) 6, "机载PHM获取数据"),
    HEARTBEAT((short) 5, "心跳包");

    public final short type;
    public final String content;

    OrderEnum(short type, String content) {
        this.type = type;
        this.content = content;
    }

    // case中判断使用
    public static OrderEnum getStructureEnum(Message msg) {
        short type = Optional.ofNullable(msg)
                .map(Message::getType)
                .orElse((short) 0);
        if (type != 0) {
            List<OrderEnum> objectEnums = Arrays.stream(OrderEnum.values())
                    .filter((item) -> item.getType() == type)
                    .distinct()
                    .collect(Collectors.toList());
            if (!objectEnums.isEmpty()) {
                return objectEnums.get(0);
            }
        }
        return null;
    }
}
