package com.phm.netty.server;

import com.phm.netty.config.NettyTcpProperties;
import io.netty.bootstrap.ServerBootstrap;
import io.netty.channel.nio.NioEventLoopGroup;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import javax.annotation.Resource;

/**
 * @Description NettyServerBoot 服务端启动类
 *
 * @Author WGK
 * @Date 2023/9/14 11:50
 */
@Slf4j
@Component
public class NettyTcpServerBoot {
    @Resource
    NioEventLoopGroup boosGroup;
    @Resource
    NioEventLoopGroup workerGroup;
    final ServerBootstrap serverBootstrap;

    final
    NettyTcpProperties nettyTcpProperties;

    public NettyTcpServerBoot(ServerBootstrap serverBootstrap, NettyTcpProperties nettyTcpProperties) {
        this.serverBootstrap = serverBootstrap;
        this.nettyTcpProperties = nettyTcpProperties;
    }

    /**
     * 启动netty服务端
     *
     * @throws InterruptedException 异常
     */
    @PostConstruct
    public void start() throws InterruptedException {

        // 绑定监听端口启动
        serverBootstrap.bind(nettyTcpProperties.getPort()).sync();

        // 备用端口
        serverBootstrap.bind(nettyTcpProperties.getPortSalve()).sync();
        log.info("启动Netty: {},{}", nettyTcpProperties.getPort(), nettyTcpProperties.getPortSalve());
    }

    /**
     * 关闭netty
     */
    @PreDestroy
    public void close() {
        log.info("关闭Netty");
        boosGroup.shutdownGracefully();
        workerGroup.shutdownGracefully();
    }
}
