package com.phm.netty.server;

import com.phm.netty.server.handler.ByteArrayMessageHandler;
import com.phm.netty.server.handler.HeartbeatHandler;
import io.netty.channel.ChannelInitializer;
import io.netty.channel.ChannelPipeline;
import io.netty.channel.socket.SocketChannel;
import io.netty.handler.codec.bytes.ByteArrayDecoder;
import io.netty.handler.codec.bytes.ByteArrayEncoder;
import io.netty.handler.timeout.IdleStateHandler;
import org.springframework.stereotype.Component;

/**
 * @Description NettyServerHandler 服务端初始类
 * @Author WGK
 * @Date 2023/9/13 13:44
 */
@Component
public class NettyTcpServerInitialize extends ChannelInitializer<SocketChannel> {

    @Override
    protected void initChannel(SocketChannel socketChannel) throws Exception {
        ChannelPipeline pipeline = socketChannel.pipeline();
        // 添加IdleStateHandler来处理空闲状态
        pipeline.addLast(new IdleStateHandler(0, 5, 0));
        // 添加心跳处理器
        pipeline.addLast(new HeartbeatHandler());
        pipeline.addLast(new ByteArrayDecoder());
        pipeline.addLast(new ByteArrayEncoder());
        // 对数据进行最终处理
        pipeline.addLast(new ByteArrayMessageHandler());
    }
}

