package com.phm.netty.server.handler;

import cn.hutool.core.collection.CollectionUtil;
import com.phm.netty.domain.Message;
import com.phm.netty.utils.ChannelMap;
import io.netty.channel.Channel;
import io.netty.channel.ChannelHandler;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.SimpleChannelInboundHandler;
import io.netty.util.AttributeKey;
import lombok.extern.slf4j.Slf4j;

/**
 * @Description HexByteArrayServerHandler 服务端处理器，接收并处理十六进制字节数组消息
 * @Author WGK
 * @Date 2023/9/21 14:25
 */
@ChannelHandler.Sharable
@Slf4j
public class HexByteArrayServerHandler extends SimpleChannelInboundHandler<byte[]> {

    @Override
    public void handlerAdded(ChannelHandlerContext ctx) {
        log.info("有新的连接：[{}]", ctx.channel().id().asLongText());
    }

    @Override
    protected void channelRead0(ChannelHandlerContext ctx, byte[] msg) throws Exception {
        // 在这里处理接收到的十六进制字节数组消息
        log.info("Received message: ");
        ctx.writeAndFlush(msg);
    }

    /**
     * 设备下线处理
     *
     * @param ctx ctx
     */
    @Override
    public void handlerRemoved(ChannelHandlerContext ctx) {
        log.info("设备下线了:{}", ctx.channel().id().asLongText());
        // map中移除channel
        removeId(ctx);
    }

    /**
     * 设备连接异常处理
     *
     * @param ctx   ctx
     * @param cause cause
     */
    @Override
    public void exceptionCaught(ChannelHandlerContext ctx, Throwable cause) {
        // 打印异常
        log.info("异常：{}", cause.getMessage());
        // map中移除channel
        removeId(ctx);
        // 关闭连接
        ctx.close();
    }

    private void removeId(ChannelHandlerContext ctx) {
        AttributeKey<String> key = AttributeKey.valueOf("id");
        // 获取channel中id
        String id = ctx.channel().attr(key).get();
        // map移除channel
        if (CollectionUtil.isNotEmpty(ChannelMap.getChannelMap())) {
            ChannelMap.getChannelMap().remove(id);
        } else {
            log.info("ChannelMap === 为空");
        }
    }

    public void channelWrite(Channel channel, Message message) throws Exception {
        if (null == channel) {
            throw new RuntimeException("客户端已离线");
        }
        channel.writeAndFlush(message);
    }
}
