package com.phm.netty.service.impl;

import java.util.ArrayList;
import java.util.List;

import cn.hutool.core.util.ObjectUtil;
import com.phm.manage.domain.Sortie;
import com.phm.manage.enums.DataTypeEnum;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.phm.common.config.PHMConfig;
import com.phm.manage.domain.OrderConfig;
import com.phm.manage.domain.OrderInfo;
import com.phm.manage.domain.SortieParameter;
import com.phm.manage.domain.common.CommonResult;
import com.phm.manage.enums.OrderStatus;
import com.phm.manage.service.IDataDownResultService;
import com.phm.manage.service.IOrderConfigService;
import com.phm.manage.service.IOrderInfoService;
import com.phm.manage.service.ISortieParameterService;
import com.phm.manage.service.ISortieService;
import com.phm.manage.util.CsvUtils;
import com.phm.manage.util.JsonUtils;
import com.phm.netty.domain.Message;
import com.phm.netty.enums.OrderEnum;
import com.phm.netty.service.IProcessService;
import com.phm.system.service.ISysDictTypeService;

import cn.hutool.core.lang.Console;
import cn.hutool.core.util.IdUtil;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import lombok.extern.slf4j.Slf4j;

/**
 * @Description ProcessService
 * @Author WGK
 * @Date 2023/9/22 9:54
 */

@Service
@Slf4j
public class ProcessService implements IProcessService {

    @Autowired
    private IOrderInfoService orderInfoService;

    @Autowired
    private ISysDictTypeService dictTypeService;

    @Autowired
    private ISortieService sortieService;

    @Autowired
    private IOrderConfigService orderConfigService;

    @Autowired
    private IDataDownResultService resultService;

    @Autowired
    private ISortieParameterService sortieParameterService;

    @Override
    public Message orderHandle(Message message) throws Exception {
        JSONObject jsonObject = JSONUtil.parseObj(message.getData());
        String orderBatchId = jsonObject.getStr("id");
        String orderCode = jsonObject.getStr("orderCode");
        OrderConfig orderConfig = orderConfigService.selectOrderConfigByCode(orderCode);
        // 保存要执行的指令信息
        OrderInfo orderInfo = new OrderInfo();
        orderInfo.setOrderBatchId(orderBatchId);
        orderInfo.setOrderCode(orderConfig.getOrderCode());
        orderInfo.setOrderName(orderConfig.getName());
        orderInfo.setOrderType(orderConfig.getType());
        // 设置待执行状态
        orderInfo.setStatus(OrderStatus.S_0.getCode());
        orderInfoService.insertOrderInfo(orderInfo);
        Message msg = new Message();
        msg.setType(OrderEnum.RESPONSE.getType()).setData(
            JsonUtils.convertJson(CommonResult.success("{\"id\": " + orderBatchId + ",orderCode:" + orderCode + "}")));
        return msg;
    }

    @Override
    public void timing(Message message) throws Exception {
        log.info("校时功能");
        JSONObject jsonObject = JSONUtil.parseObj(message.getData());
        String timestamp = jsonObject.getStr("timestamp");
        String osName = System.getProperty("os.name").toLowerCase();
        try {
            if (osName.contains("windows")) {
                String date = timestamp.substring(0, 10);
                String time = timestamp.substring(11);
                Runtime.getRuntime().exec("cmd /c date " + date); // 修改应用服务器年月日
                Runtime.getRuntime().exec("cmd /c time " + time);// 修改应用服务器时分秒
            }
            if (osName.contains("linux")) {
                String[] command = {"date", "-s", timestamp};
                Process pr = Runtime.getRuntime().exec(command);
                pr.waitFor();
            }
        } catch (Exception exception) {
            log.error(exception.getMessage());
        }
        log.info("校时成功");
    }

    @Override
    public List<OrderConfig> getParameterConfig(Message message) throws Exception {
        return orderConfigService.selectOrderConfigList(null);
    }

    @Override
    public List<String> handleData(Message message, String sortieNo) throws Exception {
        JSONObject jsonObject = JSONUtil.parseObj(message.getData());
        short type = message.getType();
        log.info("msg---:{}", message);
        String dataJson = "";

        // 数链仿真系统获取数据
        if (OrderEnum.SIMULATION.getType() != type) {
            log.info("数链仿真系统获取数据");
            String cmdId = jsonObject.getStr("cmdid");
            dataJson = jsonObject.getStr("params");
        }

        // 机载PHM获取数据
        if (OrderEnum.AIRBORNE.getType() == type) {
            // 数据
            log.info("机载PHM获取数据");
        }
        // 参数数据存放位置
        String parameterDataPath =
                PHMConfig.getCsvFilePath() + CsvUtils.PARAMETER_DATA_PATH + CsvUtils.extractFilename(sortieNo);
        CsvUtils.jsonToFileCsv(dataJson, parameterDataPath);
        SortieParameter parameter = new SortieParameter();
        parameter.setDataPath(parameterDataPath).setSortieNo(sortieNo).setBatchNo(IdUtil.getSnowflakeNextIdStr())
                .setType(DataTypeEnum.SOURCE_DATA.getType());
        sortieParameterService.insertSortieParameter(parameter);
        Sortie sortie = sortieService.selectSortieByNumber(sortieNo);
        // 新增架次信息
        if (ObjectUtil.isEmpty(sortie)) {
            sortie = new Sortie();
            sortie.setSortieNumber(sortieNo);
            sortieService.insertSortie(sortie);
        }

        return null;
    }

    public static void main(String[] args) {
        // List<String> ss = new ArrayList<>();
        // ss.add("参数一");
        // JSONArray jsonArray = CsvUtils.getCsvDataByHeaders("D:\\phm\\dataPath\\csv" +
        // "\\parameterData\\JC02" + ".csv", ss);
        // // 打印JSON数组对象
        // Console.log(jsonArray);

        List<String> t = CsvUtils.getCsvHeaders("D:\\phm\\dataPath\\csv" + "\\parameterData\\JC02" + ".csv");
        Console.log(t);
        // System.out.println(jsonArray.toString());
        // int numberOfRandomNumbers = 10000;
        // double minValue = 0.0000;
        // double maxValue = 1.9999;
        //
        // Random random = new Random();
        //
        // for (int i = 0; i < numberOfRandomNumbers; i++) {
        // double randomValue = minValue + (maxValue - minValue) * random.nextDouble();
        // System.out.printf("%.4f%n", randomValue);
        // }
        // int numberOfDataPoints = 2000;
        // String pattern = "yyyy/MM/dd HH:mm:ss";
        // String startTime = "2023/11/20 13:08:02";
        //
        // DateTimeFormatter formatter = DateTimeFormatter.ofPattern(pattern);
        // LocalDateTime currentTime = LocalDateTime.parse(startTime, formatter);
        //
        // for (int i = 0; i < numberOfDataPoints; i++) {
        // for (int i1 = 0; i1 < 5; i1++) {
        // System.out.println(formatter.format(currentTime));
        // }
        // currentTime = currentTime.plusSeconds(1);
        // }
    }
}
