package com.phm.netty.utils;

import java.nio.ByteBuffer;

/**
 * @Description ByteUtils
 * @Author WGK
 * @Date 2023/9/20 16:43
 */
public class ByteUtils {

    /**
     * 返回由字节数组中的指定的两个字节转换来的 16 位有符号整数
     *
     * @param bytes      字节数组
     * @param startIndex 起始下标
     * @return 由两个字节构成的 16 位有符号整数
     */
    public static short toShort(byte[] bytes, int startIndex) {
        short shortValue = 0;
        if (bytes.length >= 2) {
            // 使用 ByteBuffer 读取前2个字节并转换为 short
            ByteBuffer buffer = ByteBuffer.wrap(bytes, startIndex, 2);
            shortValue = buffer.getShort();
        }
        return shortValue;
    }

    /**
     * 返回由字节数组中的指定的四个字节转换来的 32 位有符号整数
     *
     * @param bytes      字节数组
     * @param startIndex 起始下标
     * @return 由四个字节构成的 32 位有符号整数
     */

    public static int toInt(byte[] bytes, int startIndex) {
        int intValue = 0;
        if (bytes.length >= 2) {
            // 使用 ByteBuffer 读取前2个字节并转换为 short
            ByteBuffer buffer = ByteBuffer.wrap(bytes, startIndex, 4);
            intValue = buffer.getInt();
        }
        return intValue;
    }

    /**
     * int shor 类型转byte[]
     *
     * @param object 被转对象
     * @param len 数组长度
     * @return 输出对应长度字节数组
     */
    public static byte[] getBytes(Object object, int len) {
        ByteBuffer buffer = ByteBuffer.allocate(len);
        if (object instanceof Integer) {
            // 使用ByteBuffer将int转为byte数组
            buffer.putInt((Integer) object);
        } else if (object instanceof Short) {
            // 使用ByteBuffer将Short转为byte数组
            buffer.putShort((Short) object);
        }
        return buffer.array();
    }
}
